@@ -21,44 +21,14 @@ logging.basicConfig(level=logging.INFO, format='%(levelname)s:%(message)s')
 #############################
 ###    Functionality      ###
 #############################
-# conf_server = {
-#     "USERM_HOST": "user-management.prod.firefly.ai",
-#     "USERM_PORT": 5007,
-#     "DATASET_HOST": "data-service.prod.firefly.ai",
-#     "DATASET_PORT": 5001,
-#     "PREDICTION_HOST": "prediction-manager.prod.firefly.ai",
-#     "PREDICTION_PORT": 5017,
-#     "HAL_HOST": "task-manager.prod.firefly.ai",
-#     "HAL_PORT": 5013,
-#     "REPORT_HOST": "reports.prod.firefly.ai",
-#     "REPORT_PORT": 5015,
-#     "ENSEMBLES_HOST": "ensembles.prod.firefly.ai",
-#     "ENSEMBLES_PORT": 80,
-#     "TEMPLATES_HOST": "templates.prod.firefly.ai",
-#     "TEMPLATES_PORT": 5011
-# }
 
 class MyWhatify:
     #############################
     #######    API's      #######
     #############################
-    # halClient = None
-    # predClient = None
-    # umClient = None
-    # dataset_client = None
-    # report_client = None
     user_token = None
 
     def __init__(self):
-        # self.auth = authenticate email, password
-        # self.halClient = HalClient(host=conf_server['HAL_HOST'], port=conf_server['HAL_PORT'], use_https=True)
-        # self.predClient = PredictionClient(host=conf_server['PREDICTION_HOST'], port=conf_server['PREDICTION_PORT'],
-        #                               use_https=True)
-        # self.umClient = UMClient(host=conf_server['USERM_HOST'], port=conf_server['USERM_PORT']),  # use_https=True)
-        # self.dataset_client = DatasetClient(host=conf_server['DATASET_HOST'], port=conf_server['DATASET_PORT'],
-        #                                use_https=True)
-        # self.report_client = ReportsClient(host=conf_server['REPORT_HOST'], port=conf_server['REPORT_PORT'], use_https=True)
-        # self.ensembles_client = EnsemblesClient(host=conf_server['ENSEMBLES_HOST'], port=conf_server['ENSEMBLES_PORT'])
         pass
 
     def authenticate(self, username, password):
@@ -110,9 +80,12 @@ class MyWhatify:
                 print(e)
         return source_id
 
-    def preparing_data_set(self, source_id, data_set_name, problem_type=ProblemType.CLASSIFICATION, target='class',
-                           retype_columns={'car_id': my_toolkit.vars_global.FeatureType.CATEGORICAL},
-                           sample_id=['car_id'], wait=True):
+    def preparing_data_set(self, source_id, data_set_name, sample_id=None, retype_columns=None, target='class',
+                           problem_type=ProblemType.CLASSIFICATION, wait=True):
+        if sample_id is None:
+            sample_id = ['car_id']
+        if retype_columns is None:
+            retype_columns = {'car_id': my_toolkit.vars_global.FeatureType.CATEGORICAL}
         with allure.step('Preparing Dataset name: ' + str(data_set_name) + ' source_id= ' + str(source_id) +
                      ' problem_type: ' + str(problem_type) + ' target: ' + str(target) + ' wait: ' + str(wait)):
             dataset_id = -1
